@@ -25,7 +25,7 @@ import datetime
 import logging
 import logging.config
 
-# current_path = Path(__file__).parent
+current_path = Path(__file__).parent
 
 
 def run(inputfile: Path, outputdir: Path, config: Path, ncrna_lst: list) -> None:
@@ -69,7 +69,7 @@ def main():
     )
     configure = parser.parse_args()
 
-    logging.config.fileConfig("./resource/logging.conf")
+    logging.config.fileConfig(f"{current_path}/resource/logging.conf")
     logger = logging.getLogger("EVAtool")
     log_name = logger.handlers[0].baseFilename
     logger.handlers[0].baseFilename = log_name.replace("evatool.log", f"{configure.output}/test.log")
